==> dl.php?src=linea21_2_5_0.zip: linea21/languages/en/lang_dashboard.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['dashboard']['section'] = "dashboard";

/*	nommage des modules
 *  	*/
$lang['dashboard']['name'] = "value";
$lang['dashboard']['name_pluriel'] = "value(s)";
$lang['dashboard']['confirm_add'] = "Value successfully added\n";
$lang['dashboard']['confirm_mod'] = "Value successfully updated\n";
$lang['dashboard']['confirm_sup'] = "Value successfully deleted\n";




/*	nommage public
 *  	*/
$lang['dashboard']['list_public']="Dashboard";

$lang['dashboard']['h1_public_comment']="The dashboard offers a global vision of the various indicators which make up the evaluation of our sustainable development approach.<br />";
$lang['dashboard']['h1_public_comment_anim']="The dashboard represents your city's sustainable development appraisal.<br />";

$lang['dashboard']['mode_aff']="Viewing mode";
$lang['dashboard']['mode_by_project']="Project view";
$lang['dashboard']['mode_by_finality']="Purpose view";
$lang['dashboard']['mode_aff_info']="General informations";
$lang['dashboard']['mode_aff_evaluation']="Assessment criteria";
$lang['dashboard']['mode_aff_provider']="Provider";
$lang['dashboard']['mode_aff_rules']="Legal framework";
$lang['sdi']['goal_public']="Public goals";
$lang['sdi']['consulting_public']="Recommendations for indicator improvement";
$lang['dashboard']['associated_projects']='Associated project(s)';

$lang['dashboard']['tab-attached']='Strategic indicators';
$lang['dashboard']['tab-not-attached']='Common indicators';
$lang['dashboard']['tab-all']='All';

/* informations affichages tableau
 * */
$lang['dashboard']['list_public_summary']="Indicator values related to %s";
$lang['dashboard']['graphic_value']="graphic value";
$lang['dashboard']['numeric_value']="numerical value";
$lang['dashboard']['tendencies_value']="trends";
$lang['dashboard']['label_value']="indicator label";

$lang['dashboard']['evaluation_values_summary']="Assessment criteria values for the current indicator";
$lang['dashboard']['all_values_summary']="Value table for the current indicator";

$lang['dashboard']['multivalue_label']="label";
$lang['dashboard']['multivalue_value']="value";
$lang['dashboard']['multivalue_distribution']="distribution";
$lang['dashboard']['multivalue_total']="total";
$lang['dashboard']['global_rate']="Global rate";
$lang['dashboard']['cagr']="<abbr title=\"Compound Annual Growth Rate\">CAGR</abbr>";

$lang['dashboard']['to_detail_chart']="see pie chart";
$lang['dashboard']['negative_values_notice']="[negative values not displayed]";

/*	nommage rubrique module
 *  	*/
$lang['dashboard']['add'] = "Add new " . $lang['dashboard']['name'];
$lang['dashboard']['rap'] = "Create a report";
$lang['dashboard']['mod'] = "Edit value";
$lang['dashboard']['sup'] = "Delete " . $lang['dashboard']['name'];
$lang['dashboard']['det'] = "Indicator values";
$lang['dashboard']['list'] = "Dashboard ";

$lang['dashboard']['embed_chart'] = "<strong>You can embed this chart dynamically on any webpage or application.</strong><br />To do so, simply copy URL or iframe code by clicking one of these buttons. <br/><span class=\"param\">Image width and height (in pixels) can be modified by changing <kbd>w/</kbd> and <kbd>h/</kbd> parameters in URL or <kbd>width</kbd> and <kbd>height</kbd> values in embed code.</span>";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['dashboard']['add_title1'] = "Add new " . $lang['dashboard']['name'];
$lang['dashboard']['recap_commment'] = "no comments";
$lang['dashboard']['confirmation'] = "confirm registration";


/*	nommage rubrique sup
 *  	*/
$lang['dashboard']['sup_value_warning'] = "Are you sure you want to delete this " . $lang['dashboard']['name'] . "?";


/*	nommage élément rubrique

*  	*/
$lang['dashboard']['value'] = "indicator value";
$lang['dashboard']['threshold_value']="threshold value";
$lang['dashboard']['historic'] = "Indicator balance";
$lang['dashboard']['rep_graph'] = "Graphic view of the indicator";
$lang['dashboard']['sdi_info'] = "Indicator name";
$lang['dashboard']['scale'] = "associated measuring scale";
$lang['dashboard']['date'] = "publication date";
$lang['dashboard']['day'] = "day";
$lang['dashboard']['month'] = "month";
$lang['dashboard']['year'] = "year";
$lang['dashboard']['rate'] = "evolution rate";
$lang['dashboard']['comment'] = "comment";
$lang['dashboard']['comment_status'] = "comment status";
$lang['dashboard']['public'] = "public";
$lang['dashboard']['private'] = "private";
$lang['dashboard']['previous_value'] = "previous value: %s";

/*	nommage quickbox
 *  	*/
$lang['dashboard']['qb_add_title'] = " latest additions in: ";
$lang['dashboard']['qb_mod_title'] = " latest modifications in: ";


/*	divers
 *  	*/
$lang['dashboard']['select_choice'] = "-- Choose in list --";
$lang['dashboard']['facultatif'] = "optional";
$lang['dashboard']['aff_dashboard_e'] = "Show evaluation criteria";
$lang['dashboard']['aff_dashboard_r'] = "Show legal references";
$lang['dashboard']['aff_dashboard_p'] = "Show provider address";
$lang['dashboard']['novalue'] = "No value available";
$lang['dashboard']['value_tendance'] = "Indicator overall trend";
$lang['dashboard']['tendance_asc'] = "upward";
$lang['dashboard']['tendance_desc'] = "downward";
$lang['dashboard']['all_value'] = "All values for this indicator";
$lang['dashboard']['barre'] = "Indicator's position relative to threshold";
$lang['dashboard']['global_value'] = "global value";
$lang['dashboard']['det_sdi'] = "Show general information on this indicator";
$lang['dashboard']['det_sdi2'] = "General information";
$lang['dashboard']['download_chart'] = "download chart";
$lang['dashboard']['session-stored']="%s indicators are stored in session";
$lang['dashboard']['last_year_reference']="Last reference year: %s";

/*	messages
 *  	*/


$lang['dashboard']['object_notvalue'] = "A numerical value is required for this indicator";
$lang['dashboard']['object_notgoodvalue'] = "Value must be within the range of measurement";


/*	rubrique d'aide
 *  	*/
$lang['dashboard']['help_add1'] = "To add a new value, please insert the required information in the form above";
$lang['dashboard']['help_add2'] = "Click on 'measuring information' to display the threshold, minimum and maximum values as well as frequency of collection for the current indicator";
$lang['dashboard']['help_add3'] = "Click on '" . $lang['dashboard']['all_value'] . "' to display all indicator values for this scale";
$lang['dashboard']['help_add4'] = "If you are not satisfied with the summary, click the 'review parameters' button to make new changes";
$lang['dashboard']['help_add5'] = "Enter a numerical value between the indicator's minimum and maximum values";
$lang['dashboard']['help_add6'] = "Fields marked with an asterisk are required";


$lang['dashboard']['help_list1'] = "Click on indicator label to display detailed values for a scale/indicator pair";
$lang['dashboard']['help_list2'] = "Add a new value for this scale/indicator pair by clicking on the associated addition icon";
$lang['dashboard']['help_list3'] = "You can select a different scale to display its own dashboard: all indicators for this scale will appear on the dashboard.";
$lang['dashboard']['help_list4'] = "Each indicator is associated with a visual meter giving you a global overview of the dashboard for a given scale. If the meter's arrow is beyond the threshold, then the last value recorded for this indicator exceeded the threshold";
$lang['dashboard']['help_list5'] = "For more than two values at a given scale, a trend icon appears next to the visual meter.";
$lang['dashboard']['help_list6'] = "The last value of an indicator/scale pair is displayed next to the visual meter ";
$lang['dashboard']['help_list7'] = "A global visual meter is featured at the top of this page, and provides an overall view of your dashboard for the current scale.";
$lang['dashboard']['help_list8'] = "Tip: Leaving your mouse cursor over the different elements of the page will make a tooltip appear with additional information";


$lang['dashboard']['help_mod1'] = "To edit a value, you can edit the various fields in the form above";
$lang['dashboard']['help_mod2'] = "Click on 'measuring information' to display the threshold, minimum and maximum values as well as frequency of collection for the current indicator";
$lang['dashboard']['help_mod3'] = "Click on \"" . $lang['dashboard']['all_value'] . "\" to display all indicator values for this scale";
$lang['dashboard']['help_mod4'] = "If you are not satisfied with the summary, click the 'review parameters' button to make new changes";
$lang['dashboard']['help_mod5'] = "Enter a numerical value between the indicator's minimum and maximum values";
$lang['dashboard']['help_mod6'] = "Fields marked with an asterisk are required";


$lang['dashboard']['help_rap1'] = "The report is published in PDF or Word format, readable with Acrobat Reader, Microsoft Office or LibreOffice";
$lang['dashboard']['help_rap2'] = "Choose among the options above to create your report";
$lang['dashboard']['help_rap3'] = "Click the 'cancel' button at any time to abort publication";


$lang['dashboard']['help_det2'] = "Add a new value for this scale/indicator pair by clicking on the associated addition icon.";
$lang['dashboard']['help_det3'] = "Edit a value for this scale/indicator pair by clicking on the associated addition icon.";
$lang['dashboard']['help_det4'] = "Delete a value for this scale/indicator pair by clicking on the associated addition icon.";
$lang['dashboard']['help_det1'] = "Caution: a value is associated with an indicator but also a scale";
$lang['dashboard']['help_det5'] = "To display an indicator's general information, providers, legal references and evaluation criteria, click on display this information at the bottom of this page.";


$lang['dashboard']['help_sup1'] = "When clicking the 'delete' button, value is permanently deleted";
$lang['dashboard']['help_sup2'] = "If you want to only disable the value, switch its status to 'draft'.";
?>

==> dl.php?src=linea21_2_7_0.zip: linea21/languages/en/lang_dashboard.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['dashboard']['section'] = "dashboard";

/*	nommage des modules
 *  	*/
$lang['dashboard']['name'] = "value";
$lang['dashboard']['name_pluriel'] = "value(s)";
$lang['dashboard']['confirm_add'] = "Value successfully added\n";
$lang['dashboard']['confirm_mod'] = "Value successfully updated\n";
$lang['dashboard']['confirm_sup'] = "Value successfully deleted\n";




/*	nommage public
 *  	*/
$lang['dashboard']['list_public']="Dashboard";

$lang['dashboard']['h1_public_comment']="The dashboard offers a global vision of the various indicators which make up the evaluation of our sustainable development approach.<br />";
$lang['dashboard']['h1_public_comment_anim']="The dashboard represents your city's sustainable development appraisal.<br />";

$lang['dashboard']['mode_aff']="Viewing mode";
$lang['dashboard']['mode_by_project']="Project view";
$lang['dashboard']['mode_by_finality']="Purpose view";
$lang['dashboard']['mode_aff_info']="General informations";
$lang['dashboard']['mode_aff_evaluation']="Assessment criteria";
$lang['dashboard']['mode_aff_provider']="Provider";
$lang['dashboard']['mode_aff_rules']="Legal framework";
$lang['sdi']['goal_public']="Public goals";
$lang['sdi']['consulting_public']="Recommendations for indicator improvement";
$lang['dashboard']['associated_projects']='Associated project(s)';

$lang['dashboard']['tab-attached']='Strategic indicators';
$lang['dashboard']['tab-not-attached']='Common indicators';
$lang['dashboard']['tab-all']='All';

/* informations affichages tableau
 * */
$lang['dashboard']['list_public_summary']="Indicator values related to %s";
$lang['dashboard']['graphic_value']="graphic value";
$lang['dashboard']['numeric_value']="numerical value";
$lang['dashboard']['tendencies_value']="trends";
$lang['dashboard']['label_value']="indicator label";

$lang['dashboard']['evaluation_values_summary']="Assessment criteria values for the current indicator";
$lang['dashboard']['all_values_summary']="Value table for the current indicator";

$lang['dashboard']['multivalue_label']="label";
$lang['dashboard']['multivalue_value']="value";
$lang['dashboard']['multivalue_distribution']="distribution";
$lang['dashboard']['multivalue_total']="total";
$lang['dashboard']['multivalue_mean']="mean";
$lang['dashboard']['global_rate']="Global rate";
$lang['dashboard']['cagr']="<abbr title=\"Compound Annual Growth Rate\">CAGR</abbr>";

$lang['dashboard']['to_detail_chart']="see pie chart";
$lang['dashboard']['negative_values_notice']="[negative values not displayed]";

/*	nommage rubrique module
 *  	*/
$lang['dashboard']['add'] = "Add new " . $lang['dashboard']['name'];
$lang['dashboard']['rap'] = "Create a report";
$lang['dashboard']['mod'] = "Edit value";
$lang['dashboard']['sup'] = "Delete " . $lang['dashboard']['name'];
$lang['dashboard']['det'] = "Indicator values";
$lang['dashboard']['list'] = "Dashboard ";

$lang['dashboard']['embed_chart'] = "<strong>You can embed this chart dynamically on any webpage or application.</strong><br />To do so, simply copy URL or iframe code by clicking one of these buttons. <br/><span class=\"param\">Image width and height (in pixels) can be modified by changing <kbd>w/</kbd> and <kbd>h/</kbd> parameters in URL or <kbd>width</kbd> and <kbd>height</kbd> values in embed code.</span>";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['dashboard']['add_title1'] = "Add new " . $lang['dashboard']['name'];
$lang['dashboard']['recap_commment'] = "no comments";
$lang['dashboard']['confirmation'] = "confirm registration";


/*	nommage rubrique sup
 *  	*/
$lang['dashboard']['sup_value_warning'] = "Are you sure you want to delete this " . $lang['dashboard']['name'] . "?";


/*	nommage élément rubrique

*  	*/
$lang['dashboard']['value'] = "indicator value";
$lang['dashboard']['threshold_value']="threshold value";
$lang['dashboard']['historic'] = "Indicator balance";
$lang['dashboard']['rep_graph'] = "Graphic view of the indicator";
$lang['dashboard']['sdi_info'] = "Indicator name";
$lang['dashboard']['scale'] = "associated measuring scale";
$lang['dashboard']['date'] = "publication date";
$lang['dashboard']['day'] = "day";
$lang['dashboard']['month'] = "month";
$lang['dashboard']['year'] = "year";
$lang['dashboard']['rate'] = "evolution rate";
$lang['dashboard']['comment'] = "comment";
$lang['dashboard']['comment_status'] = "comment status";
$lang['dashboard']['public'] = "public";
$lang['dashboard']['private'] = "private";
$lang['dashboard']['last_analysis'] = "Tendency / Analysis";
$lang['dashboard']['last_analysis_notice'] = "Share your analysis on the indicator page";
$lang['dashboard']['previous_value'] = "previous value: %s";

/*	nommage quickbox
 *  	*/
$lang['dashboard']['qb_add_title'] = " latest additions in: ";
$lang['dashboard']['qb_mod_title'] = " latest modifications in: ";


/*	divers
 *  	*/
$lang['dashboard']['select_choice'] = "-- Choose in list --";
$lang['dashboard']['facultatif'] = "optional";
$lang['dashboard']['aff_dashboard_e'] = "Show evaluation criteria";
$lang['dashboard']['aff_dashboard_r'] = "Show legal references";
$lang['dashboard']['aff_dashboard_p'] = "Show provider address";
$lang['dashboard']['novalue'] = "No value available";
$lang['dashboard']['value_tendance'] = "Indicator overall trend";
$lang['dashboard']['tendance_asc'] = "upward";
$lang['dashboard']['tendance_desc'] = "downward";
$lang['dashboard']['all_value'] = "All values for this indicator";
$lang['dashboard']['barre'] = "Indicator's position relative to threshold";
$lang['dashboard']['global_value'] = "global value";
$lang['dashboard']['det_sdi'] = "Show general information on this indicator";
$lang['dashboard']['det_sdi2'] = "General information";
$lang['dashboard']['download_chart'] = "download chart";
$lang['dashboard']['session-stored']="%s indicators are stored in session";
$lang['dashboard']['last_year_reference']="Last reference year: %s";
$lang['dashboard']['go_back_to_project']="Value has been added successfully. <strong>Go back to action</strong>";

/*	messages
 *  	*/


$lang['dashboard']['object_notvalue'] = "A numerical value is required for this indicator";
$lang['dashboard']['object_notgoodvalue'] = "Value must be within the range of measurement";


/*	rubrique d'aide
 *  	*/
$lang['dashboard']['help_add1'] = "To add a new value, please insert the required information in the form above";
$lang['dashboard']['help_add2'] = "Click on 'measuring information' to display the threshold, minimum and maximum values as well as frequency of collection for the current indicator";
$lang['dashboard']['help_add3'] = "Click on '" . $lang['dashboard']['all_value'] . "' to display all indicator values for this scale";
$lang['dashboard']['help_add4'] = "If you are not satisfied with the summary, click the 'review parameters' button to make new changes";
$lang['dashboard']['help_add5'] = "Enter a numerical value between the indicator's minimum and maximum values";
$lang['dashboard']['help_add6'] = "Fields marked with an asterisk are required";


$lang['dashboard']['help_list1'] = "Click on indicator label to display detailed values for a scale/indicator pair";
$lang['dashboard']['help_list2'] = "Add a new value for this scale/indicator pair by clicking on the associated addition icon";
$lang['dashboard']['help_list3'] = "You can select a different scale to display its own dashboard: all indicators for this scale will appear on the dashboard.";
$lang['dashboard']['help_list4'] = "Each indicator is associated with a visual meter giving you a global overview of the dashboard for a given scale. If the meter's arrow is beyond the threshold, then the last value recorded for this indicator exceeded the threshold";
$lang['dashboard']['help_list5'] = "For more than two values at a given scale, a trend icon appears next to the visual meter.";
$lang['dashboard']['help_list6'] = "The last value of an indicator/scale pair is displayed next to the visual meter ";
$lang['dashboard']['help_list7'] = "A global visual meter is featured at the top of this page, and provides an overall view of your dashboard for the current scale.";
$lang['dashboard']['help_list8'] = "Tip: Leaving your mouse cursor over the different elements of the page will make a tooltip appear with additional information";


$lang['dashboard']['help_mod1'] = "To edit a value, you can edit the various fields in the form above";
$lang['dashboard']['help_mod2'] = "Click on 'measuring information' to display the threshold, minimum and maximum values as well as frequency of collection for the current indicator";
$lang['dashboard']['help_mod3'] = "Click on \"" . $lang['dashboard']['all_value'] . "\" to display all indicator values for this scale";
$lang['dashboard']['help_mod4'] = "If you are not satisfied with the summary, click the 'review parameters' button to make new changes";
$lang['dashboard']['help_mod5'] = "Enter a numerical value between the indicator's minimum and maximum values";
$lang['dashboard']['help_mod6'] = "Fields marked with an asterisk are required";


$lang['dashboard']['help_rap1'] = "The report is published in PDF or Word format, readable with Acrobat Reader, Microsoft Office or LibreOffice";
$lang['dashboard']['help_rap2'] = "Choose among the options above to create your report";
$lang['dashboard']['help_rap3'] = "Click the 'cancel' button at any time to abort publication";


$lang['dashboard']['help_det2'] = "Add a new value for this scale/indicator pair by clicking on the associated addition icon.";
$lang['dashboard']['help_det3'] = "Edit a value for this scale/indicator pair by clicking on the associated addition icon.";
$lang['dashboard']['help_det4'] = "Delete a value for this scale/indicator pair by clicking on the associated addition icon.";
$lang['dashboard']['help_det1'] = "Caution: a value is associated with an indicator but also a scale";
$lang['dashboard']['help_det5'] = "To display an indicator's general information, providers, legal references and evaluation criteria, click on display this information at the bottom of this page.";


$lang['dashboard']['help_sup1'] = "When clicking the 'delete' button, value is permanently deleted";
$lang['dashboard']['help_sup2'] = "If you want to only disable the value, switch its status to 'draft'.";
?>
